10. External References — setupjavax documentation

# 10. External References

AndreasPavel

  Andreas Pavel; Andreas Pavel@Wikipedia.org ; Stereobelt; Sony legt Walkman-Patentstreit mit deutschem Erfinder bei

EPYUNIT

  ePyUnit; Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez; 2010-2018; epyunit@PyPI; epyunit@GitHub; epyunit@docs@sourceforge.io

FILESYSOBJECTS

  filesysobjects; Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez; 2010,2011,2015-2017; filesysobjects@PyPI; filesysobjects@GitHub; filesysobjects-docs@sourceforge.io

IronPython

  IronPython - implementation of Python targeting the .NET Framework and Mono; IronPython.org; IronPython@Wikipedia;

JNA

  Java Native Access - JNA; jna.org; JNA@github; JNA@Wikipedia;

JSONDATA

  jsondata; Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez; 2010-2018; jsondata@PyPI; jsondata@GitHub; jsondata-docs@sourceforge.io

JythonGuide

  The Definitive Guide to Jython; JythonGuide@readthedocs.io; Authors: Josh Juneau, Jim Baker, Victor Ng, Leo Soto, Frank Wierzbicki; Version: 1.0 of 03/25/2010;

JythonUsage

  Usage; Jython Usage@Wikipedia;

Jython

  Jython - implementation of the Python to run on the Java platform; Jython.org; Jython@Wikipedia; High Profile Languages@Wikipedia;

PYSOURCEINFO

  pysourceinfo; Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez; 2010-2018; pysourceinfo@PyPI; pysourceinfo@GitHub; pysourceinfo-docs@sourceforge.io

SYSCALLS

  syscalls; Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez; 2010-2018; syscalls@PyPI; syscalls@GitHub; syscalls-docs@sourceforge.io

UnifiedSessionsManager

  UnifiedSessionsManager Virtualization and Cloud Computing (C) 2008 Ingenieurbuero Arno/Can Uestuensoez; UnifiedSessionsManager@Sourceforge.net;

WINWSL

  Windows Subsystem for Linux Documentation; WSL@Microsoft.com ; WSL@Wikipedia.org; WSL@github.com

distutils

  distutils - Building and installing Python modules; Distutils - PythonWiki@readthedocs.io; distutils2@Python.org; distutils3@Python.org;

machineids

  machineids - Identifier for VMs and PMs; Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez; 2008-2018; machineids@PyPI; machineids@GitHub; machineids-docs@sourceforge.io

platformids

  platformids - OS Type and Distribution IDs of System Platforms; Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez; 2008-2018; platformids@PyPI; platformids@GitHub; platformids-docs@sourceforge.io

pythonids

  pythonids - Python Interpreter and Compiler IDs; Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez; 2008-2018; pythonids@PyPI; pythonids@GitHub; pythonids-docs@sourceforge.io

setuppy

  setup.py - Setuptools’ documentation; setup.py@readthedocs.io

setuptools

  setuptools - Setuptools’ documentation; docs@readthedocs.io; PyPI; GitHub;

xkcd

  Profile Info; Randall Munroe; xkcd.com ; Profile Info